@@ -11,10 +11,12 @@ from ui.KineticScroller import KineticScroller
 from ui import dialogs
 from ControlBar import ControlBar
 import panel_actions
+from Headset import Headset
 from mediascanner.MediaScanner import MediaScanner
 import config
 import values
 import viewers
+from utils import maemo
 import theme
 
 import gtk
@@ -22,13 +24,6 @@ import gobject
 import os
 import time
 
-try:
-    import osso
-    import hildon
-    _HAVE_OSSO = True
-except:
-    _HAVE_OSSO = False
-    
 
 class App(object):
     """
@@ -47,9 +42,15 @@ class App(object):
 
         self.__saved_image = None
         self.__saved_image_index = -1
+        
+        # flag for indicating whether media scanning has already been scheduled
+        self.__media_scan_scheduled = False
     
-        if (_HAVE_OSSO):
-            self.__osso_context = osso.Context(values.OSSO_NAME, values.VERSION, False)
+        if (maemo.IS_MAEMO):
+            import hildon
+            import osso
+            maemo.set_osso_context(osso.Context(values.OSSO_NAME,
+                                                "1.0", False))
             self.__program = hildon.Program()
     
         # set theme
@@ -69,7 +70,7 @@ class App(object):
         self.__window.connect("key-release-event", lambda x, y: True)
         self.__window.show()    
         
-        if (_HAVE_OSSO):
+        if (maemo.IS_MAEMO):
             self.__program.add_window(self.__window)
 
         # screen pixmap
@@ -109,12 +110,16 @@ class App(object):
         self.__content_pane.add(self.__strip)
 
         self.__kscr = KineticScroller(self.__strip)
+        self.__kscr.set_touch_area(0, 108)
         self.__kscr.add_observer(self.__on_observe_strip)
 
         # set up media scanner
         mscanner = MediaScanner()
         mscanner.add_observer(self.__on_observe_media_scanner)
       
+        # watch headset button
+        Headset().add_observer(self.__on_observe_headset)
+        
        
     def __startup(self):
         """
@@ -129,28 +134,55 @@ class App(object):
                    (self.__content_pane.set_visible, [True]),
                    (self.__ctrlbar.set_visible, [True]),                   
                    (self.__root_pane.render, []),
-                   (self.__scan_media, []),
+                   (self.__scan_media, [True]),
                    (self.__ctrlbar.select_tab, [0]),
+                   (self.__setup_mmc_replacement_detection, []),
                    ]
                    
         def f():
             if (actions):
                 act, args = actions.pop(0)
-                act(*args)
+                try:
+                    act(*args)
+                except:
+                    pass
                 return True
             else:
                 return False
                 
         gobject.idle_add(f)
         
-        
 
-    def __scan_media(self):
+    def __setup_mmc_replacement_detection(self):
+
+        import dbus, dbus.glib
+        bus = dbus.SessionBus()
+        obj = bus.get_object("org.gnome.GnomeVFS.Daemon",
+                             "/org/gnome/GnomeVFS/Daemon")
+        iface = dbus.Interface(obj, 'org.gnome.GnomeVFS.Daemon')
+        iface.connect_to_signal("VolumeMountedSignal", self.__on_mount_mmc)
+
+      
+    def __on_mount_mmc(self, arg):
+    
+        def f():
+            self.__scan_media(True)
+            self.__media_scan_scheduled = False
+    
+        if (not self.__media_scan_scheduled):
+            self.__media_scan_scheduled = True
+            gobject.timeout_add(500, f)
+
+
+    def __scan_media(self, force_scan):
         """
         Scans the media root locations for media files. Will create thumbnails
         when missing.
         """
 
+        if (force_scan):
+            self.__current_mediaroots = []
+
         mediaroots = config.mediaroot()        
     
         if (`mediaroots` == `self.__current_mediaroots`):
@@ -168,6 +200,7 @@ class App(object):
 
         self.__ctrlbar.show_message("Looking for media files...")
         self.__content_pane.set_visible(False)
+        self.__thumbnailer.clear()
         self.__thumbnailer.set_visible(True)
         self.__root_pane.render()
         while (gtk.events_pending()): gtk.main_iteration()
@@ -175,13 +208,8 @@ class App(object):
 
         mscanner = MediaScanner()
         mscanner.set_thumb_folder(os.path.abspath(config.thumbdir()))
-        
-        # TODO: media types should be applied by the user to the roots
-        mtypes = mscanner.MEDIA_VIDEO | \
-                 mscanner.MEDIA_AUDIO | \
-                 mscanner.MEDIA_IMAGE
-        
-        mscanner.set_media_roots([ (uri, mtypes) for uri in mediaroots ])
+               
+        mscanner.set_media_roots(mediaroots)
 
         now = time.time()
         mscanner.scan()
@@ -197,6 +225,8 @@ class App(object):
         for v in self.__viewers:
             v.update_media(mscanner)
             self.__viewer_states[v].thumbs_loaded = False
+            self.__viewer_states[v].selected_item = -1
+            self.__viewer_states[v].item_offset = 0
 
         self.__thumbnailer.set_visible(False)
         self.__content_pane.set_visible(True)
@@ -242,7 +272,7 @@ class App(object):
         if not.
         """
     
-        import MPlayer
+        from mediaplayer.MPlayer import MPlayer
         mplayer = MPlayer.MPlayer()
         
         if (not mplayer.is_available()):
@@ -312,7 +342,8 @@ class App(object):
             self.__get_vstate().caps = caps
     
         elif (cmd == src.OBS_SCAN_MEDIA):
-            self.__scan_media() #gobject.idle_add(self.__scan_media)
+            force = args[0]
+            self.__scan_media(force)
 
         elif (cmd == src.OBS_STATE_PLAYING):
             self.__ctrlbar.set_playing(True)
@@ -353,43 +384,29 @@ class App(object):
             self.__root_pane.render_buffered()
             
         elif (cmd == src.OBS_SHOW_COLLECTION):
-            #if (not self.__strip.is_visible()):
             self.__strip.set_visible(True)
             #self.__strip.render()
             #self.__strip.fx_slide_in()
             self.__get_vstate().collection_visible = True
             self.__current_viewer.set_pos(180, 0)
-            #self.__content_pane.render()
 
         elif (cmd == src.OBS_HIDE_COLLECTION):
             self.__strip.set_visible(False)
             #self.__strip.fx_slide_out()
             self.__get_vstate().collection_visible = False
             self.__current_viewer.set_pos(0, 0)
-            #self.__content_pane.render()
 
         elif (cmd == src.OBS_FULLSCREEN):
             self.__strip.set_visible(False)
             self.__ctrlbar.set_visible(False)
-            #self.__strip.fx_slide_out(wait = False)
-            #self.__ctrlbar.fx_lower()
             self.__current_viewer.set_pos(0, 0)
             self.__current_viewer.set_size(800, 480)
-            #self.__current_viewer.render()
-            #self.__root_pane.render()
 
         elif (cmd == src.OBS_UNFULLSCREEN):
             self.__strip.set_visible(True)
             self.__ctrlbar.set_visible(True)
-            #self.__strip.render()
-            #self.__ctrlbar.render()
-            #self.__strip.fx_slide_out(wait = False)
-            #self.__ctrlbar.fx_lower()
             self.__current_viewer.set_pos(180, 0)
             self.__current_viewer.set_size(620, 400)
-            #self.__current_viewer.render()
-            #self.__root_pane.render()
-            #self.__ctrlbar.render()
             
         elif (cmd == src.OBS_SHOW_MESSAGE):
             msg = args[0]
@@ -429,6 +446,9 @@ class App(object):
         elif (cmd == panel_actions.ADD):
             self.__current_viewer.do_add()
     
+        elif (cmd == panel_actions.FORCE_SPEAKER):
+            self.__current_viewer.do_toggle_speaker()
+    
         elif (cmd == panel_actions.SET_POSITION):
             pos = args[0]
             self.__current_viewer.do_set_position(pos)
@@ -450,11 +470,17 @@ class App(object):
     
         elif (cmd == src.OBS_CLICKED):
             px, py = args
-            if (px > 108):
+            if (px > 120):
                 idx = self.__strip.get_index_at(py)            
                 self.__select_item(idx)
            
            
+    def __on_observe_headset(self, src, cmd, *args):
+    
+        if (cmd == src.OBS_BUTTON_PRESSED):
+            self.__current_viewer.do_enter()
+           
+           
     def __get_vstate(self):
     
         return self.__viewer_states[self.__current_viewer]
@@ -546,7 +572,7 @@ class App(object):
             total = len(thumbnails)
             cnt = 1
             for t in thumbnails:
-                t.get_width()             
+                t.get_width()
 
                 if (cnt % 5 == 0 or (cnt == total and cnt > 5)):
                     self.__ctrlbar.show_progress("Loading %d Items..." % total,
