@@ -10,6 +10,9 @@ import gtk
 class Thumbnailer(Widget):
 
     def __init__(self, esens):
+        """
+        Class for providing visual feedback while thubmnails are being rendered.
+        """
     
         self.__buffer = Pixmap(None, 160, 120)
         self.__bg = Pixmap(None, 160, 120)
@@ -35,6 +38,10 @@ class Thumbnailer(Widget):
         # save background
         self.__bg.copy_buffer(screen, 400 - 80, 200 - 60, 0, 0, 160, 120)
         
+        
+    def clear(self):
+    
+        self.__label.set_text("")
 
       
                
