@@ -1,5 +1,5 @@
 from viewers.Viewer import Viewer
-from RadioItem import RadioItem
+from ListItem import ListItem
 from RadioThumbnail import RadioThumbnail
 from FMRadioBackend import FMRadioBackend
 from InetRadioBackend import InetRadioBackend
@@ -8,12 +8,15 @@ from ui.KineticScroller import KineticScroller
 from ui import dialogs
 from utils import maemo
 from mediabox import caps
+from mediabox.Headset import Headset
+from mediascanner.MediaItem import MediaItem
 import theme
 
 
 import gtk
 import gobject
 import os
+import dbus
 
 
 class RadioViewer(Viewer):
@@ -33,20 +36,21 @@ class RadioViewer(Viewer):
         self.__current_radio = None
         self.__volume = 50
         self.__is_on = False
-
-        Viewer.__init__(self, esens)                
+        
+        self.__speaker_on = False
+            
+        Viewer.__init__(self, esens)
 
         # stations list
         self.__list = ItemList(esens, 600, 80)
         self.add(self.__list)
         self.__list.set_size(600, 400)        
-        self.__list.set_pos(10, 0)   
+        self.__list.set_pos(10, 0)
         self.__list.set_background(theme.background.subpixbuf(185, 0, 600, 400))
-        self.__list.set_graphics(theme.item, theme.item_active)        
-        self.__list.set_font(theme.font_plain)
         self.__list.set_arrows(theme.arrows)
                 
         kscr = KineticScroller(self.__list)
+        kscr.set_touch_area(0, 440)
         kscr.add_observer(self.__on_observe_list)
               
         # add backends
@@ -58,9 +62,10 @@ class RadioViewer(Viewer):
                          InetRadioBackend))
         
         for name, icon, backend in backends:
-            item = RadioItem(name)
+            item = MediaItem()
+            item.name = name
             tn = RadioThumbnail(icon, name)
-            item.set_thumbnail(tn)
+            item.thumbnail_pmap = tn
             try:
                 self.__radios[name] = backend()
             except:
@@ -98,6 +103,10 @@ class RadioViewer(Viewer):
             msg = args[0]
             self.update_observer(self.OBS_SHOW_MESSAGE, msg)
     
+        elif (cmd == src.OBS_WARNING):
+            msg = args[0]
+            dialogs.warning("Warning", msg)
+    
         elif (cmd == src.OBS_TITLE):
             name = args[0]
             self.update_observer(self.OBS_TITLE, name)
@@ -136,10 +145,8 @@ class RadioViewer(Viewer):
             
     def __append_station(self, location, name):
 
-        title = "%s\n[%s]" % (name, location)
-        idx = self.__list.append_item(title, None)
-        self.__list.overlay_image(idx, theme.btn_load, 440, 24)
-        self.__list.overlay_image(idx, theme.remove, 540, 24)
+        item = ListItem(600, 80, name, location)
+        idx = self.__list.append_custom_item(item)
         
 
 
@@ -158,7 +165,7 @@ class RadioViewer(Viewer):
 
     def load(self, item):
     
-        name = item.get_uri()
+        name = item.name
         self.__current_radio = self.__radios[name]
         self.update_observer(self.OBS_REPORT_CAPABILITIES,
                              self.__current_radio.CAPS)
@@ -212,6 +219,12 @@ class RadioViewer(Viewer):
         self.__current_radio.add_station()
 
 
+    def do_toggle_speaker(self):
+
+        self.__speaker_on = not self.__speaker_on
+        Headset().set_force_speaker(self.__speaker_on)
+
+
     def show(self):
     
         Viewer.show(self)
