@@ -1,7 +1,7 @@
 from viewers.Viewer import Viewer
-from VideoItem import VideoItem
 from VideoThumbnail import VideoThumbnail
-from mediabox.MPlayer import MPlayer
+from mediaplayer.MPlayer import MPlayer
+import mediaplayer
 from mediabox import caps
 from ui import dialogs
 import theme
@@ -19,11 +19,6 @@ except:
     _IS_MAEMO = False
 
 
-_VIDEO_EXT = (".avi", ".flv", ".mov", ".mpeg",
-              ".mpg", ".rm", ".wmv", ".asf",
-              ".m4v", ".mp4", ".rmvb")
-
-
 class VideoViewer(Viewer):
 
     PATH = os.path.dirname(__file__)
@@ -39,8 +34,8 @@ class VideoViewer(Viewer):
         self.__is_fullscreen = False
     
         self.__items = []
-        self.__mplayer = MPlayer()    
-        self.__mplayer.add_observer(self.__on_observe_mplayer)
+        self.__player = mediaplayer.get_player_for_uri("")
+        mediaplayer.add_observer(self.__on_observe_player)
         self.__volume = 50
 
         self.__uri = ""
@@ -53,10 +48,12 @@ class VideoViewer(Viewer):
         # video screen        
         self.__screen = gtk.DrawingArea()
         self.__screen.set_double_buffered(False)
-        #self.__screen.set_sensitive(False)
         self.__screen.connect("expose-event", self.__on_expose)
         self.__layout.put(self.__screen, 0, 0)
         
+        #self.connect(self.EVENT_BUTTON_PRESS, self.__on_drag_start)
+        
+         
         
     def render_this(self):
             
@@ -69,7 +66,7 @@ class VideoViewer(Viewer):
             x, y, w, h = self.__get_frame_rect()
             screen.draw_rect(x, y, w, h, "#000000")
     
-        if (not self.__mplayer.has_video()):
+        if (not self.__player or not self.__player.has_video()):
             self.__layout.move(self.__screen, vx, vy)
             self.__screen.set_size_request(vw, vh)
             
@@ -77,35 +74,49 @@ class VideoViewer(Viewer):
 
     def __on_expose(self, src, ev):
     
-        if (self.__mplayer.has_video()):
+        if (self.__player.has_video()):
             win = self.__screen.window
             gc = win.new_gc()
             cmap = win.get_colormap()
             gc.set_foreground(cmap.alloc_color("#000000"))
-            nil, nil, w, h = src.get_allocation()
+            x, y, w, h = ev.area
+            self.__player.handle_expose(win, gc, x, y, w, h)
 
-            # mplayer has a bug where it doesn't draw over the right and
-            # bottom edges, so we have to do this ourselves
-            win.draw_rectangle(gc, False, w - 1, 0, 1, h)
-            win.draw_rectangle(gc, False, 0, h - 1, w, 1)
             
+            
+    def __on_drag_start(self, px, py):
+    
+        print "CLICKED"
+        x, y = self.get_screen_pos()
+        w, h = self.get_size()
+
+        pos = px - x
+        self.update_observer(self.OBS_POSITION, pos, w)
+        
 
 
 
-    def __on_observe_mplayer(self, src, cmd, *args):
+    def __on_observe_player(self, src, cmd, *args):
     
         if (not self.is_active()): return            
             
         if (cmd == src.OBS_STARTED):
-            print "Started MPlayer"
+            print "Started Player"
             self.update_observer(self.OBS_STATE_PAUSED)
             
         elif (cmd == src.OBS_KILLED):
-            print "Killed MPlayer"
+            print "Killed Player"
             self.__uri = ""
             self.set_title("")
             self.__screen.hide()
             self.update_observer(self.OBS_STATE_PAUSED)
+
+        elif (cmd == src.OBS_ERROR):
+            ctx, err = args
+            if (ctx == self.__context_id):
+                self.__show_error(err)
+                self.set_title("")                
+                self.__screen.hide()
             
         elif (cmd == src.OBS_PLAYING):
             ctx = args[0]
@@ -129,6 +140,10 @@ class VideoViewer(Viewer):
             if (ctx == self.__context_id):        
                 self.__uri = ""
                 self.__screen.hide()
+
+                # unfullscreen
+                if (self.__is_fullscreen): self.do_fullscreen()
+                
                 self.update_observer(self.OBS_STATE_PAUSED)
            
         elif (cmd == src.OBS_ASPECT):
@@ -138,6 +153,18 @@ class VideoViewer(Viewer):
             self.__screen.show()
 
 
+    def __show_error(self, errcode):
+    
+        if (errcode == self.__player.ERR_INVALID):
+            dialogs.error("Invalid Stream", "Cannot load this stream.")
+        elif (errcode == self.__player.ERR_NOT_FOUND):
+            dialogs.error("Not found", "Cannot find a stream to play.")
+        elif (errcode == self.__player.ERR_CONNECTION_TIMEOUT):
+            dialogs.error("Timeout", "Connection timed out.")       
+        elif (errcode == self.__player.ERR_NOT_SUPPORTED):
+            dialogs.error("Not supported", "The media format is not supported.")
+
+
     def __get_frame_rect(self):
     
         x, y = self.get_screen_pos()
@@ -176,8 +203,10 @@ class VideoViewer(Viewer):
         else:
             self.__screen.set_size_request(w2, h)
             w2, h2 = w2, h
-        self.__layout.move(self.__screen, x + (w - w2) / 2, y + (h - h2) / 2)
 
+        self.__layout.move(self.__screen, x + (w - w2) / 2, y + (h - h2) / 2)
+        print  x + (w - w2) / 2, y + (h - h2) / 2, w2, h2
+        
         while (gtk.events_pending()): gtk.main_iteration()
 
 
@@ -188,13 +217,7 @@ class VideoViewer(Viewer):
         """
             
         self.__set_aspect_ratio(self.__aspect_ratio)
-
-
-
-    def __is_video(self, uri):
-        
-        ext = os.path.splitext(uri)[1].lower()
-        return (ext in _VIDEO_EXT)
+        self.__player.set_window(self.__screen.window.xid)
 
 
     def clear_items(self):
@@ -206,17 +229,16 @@ class VideoViewer(Viewer):
     
         self.__items = []
         for item in mscanner.get_media(mscanner.MEDIA_VIDEO):
-            vitem = VideoItem(item.uri)
-            tn = VideoThumbnail(item.thumbnail,
-                                os.path.basename(item.uri))
-            vitem.set_thumbnail(tn)
-            self.__items.append(vitem)
+            if (not item.thumbnail_pmap):
+                tn = VideoThumbnail(item.thumbnail, item.name)
+                item.thumbnail_pmap = tn
+            self.__items.append(item)
            
 
     def shutdown(self):
 
-        # the music viewer already closes mplayer for us
-        #self.__mplayer.close()
+        # the music viewer already closes the player for us
+        #mediaplayer.close()
         pass
         
 
@@ -227,28 +249,28 @@ class VideoViewer(Viewer):
     
         def f():
             if (self.__screen.window.xid):
-                uri = item.get_uri()
+                uri = item.uri
                 if (uri == self.__uri): return
                 
-                self.__mplayer.set_window(self.__screen.window.xid)
+                self.__player = mediaplayer.get_player_for_uri(uri)
+                self.__player.set_window(self.__screen.window.xid)
                 if (_IS_MAEMO):
-                    self.__mplayer.set_options("-vo xv")
+                    self.__player.set_options("-vo xv")
                     # the Nokia 770 would require something like this, instead
-                    #self.__mplayer.set_options("-ao gst -ac dspmp3 "
+                    #self.__player.set_options("-ao gst -ac dspmp3 "
                     #                      "-vo xv,nokia770:fb_overlay_only:"
                     #                      "x=%d:y=%d:w=%d:h=%d" % (x, y, w, h))
                 else:
-                    self.__mplayer.set_options("-vo xv")
+                    self.__player.set_options("-vo xv")
                     
                 try:
-                    self.__context_id = self.__mplayer.load(uri)
+                    self.__context_id = self.__player.load_video(uri)
                 except:
                     self.__screen.hide()
                     return
                                 
-                #self.__scale_video()
-                self.__mplayer.set_volume(self.__volume)
-                self.__mplayer.show_text(os.path.basename(uri), 2000)
+                self.__player.set_volume(self.__volume)
+                self.__player.show_text(os.path.basename(uri), 2000)
                 self.set_title(os.path.basename(uri))                
                 self.__uri = uri
                 
@@ -259,46 +281,46 @@ class VideoViewer(Viewer):
 
     def do_enter(self):
     
-        self.__mplayer.pause()
+        self.__player.pause()
                         
 
     def do_increment(self):
     
         if (self.__volume + 5 <= 100):
             self.__volume += 5
-        self.__mplayer.set_volume(self.__volume)
+        self.__player.set_volume(self.__volume)
         self.update_observer(self.OBS_VOLUME, self.__volume)
 
         if (self.__is_fullscreen):
-            self.__mplayer.show_text("Volume %d %%" % self.__volume, 500)
+            self.__player.show_text("Volume %d %%" % self.__volume, 500)
         
         
     def do_decrement(self):
 
         if (self.__volume - 5 >= 0):
             self.__volume -= 5
-        self.__mplayer.set_volume(self.__volume)
+        self.__player.set_volume(self.__volume)
         self.update_observer(self.OBS_VOLUME, self.__volume)        
 
         if (self.__is_fullscreen):
-            self.__mplayer.show_text("Volume %d %%" % self.__volume, 500)
+            self.__player.show_text("Volume %d %%" % self.__volume, 500)
 
         
     def do_set_position(self, pos):
     
-        self.__mplayer.seek_percent(pos)
+        self.__player.seek_percent(pos)
 
 
     def do_play_pause(self):
     
-        self.__mplayer.pause()
+        self.__player.pause()
 
 
     def show(self):
     
         Viewer.show(self)
         self.update_observer(self.OBS_SET_COLLECTION, self.__items)
-        if (self.__mplayer.has_video()):
+        if (self.__player and self.__player.has_video()):
             self.__scale_video()
             self.__screen.show()
         
@@ -320,15 +342,17 @@ class VideoViewer(Viewer):
             self.update_observer(self.OBS_FULLSCREEN)
             # what a hack! but it works and it allows to unfullscreen mplayer!
             gtk.gdk.keyboard_grab(self.__screen.get_toplevel().window)
+            gtk.gdk.pointer_grab(self.__screen.get_toplevel().window)
         else:
             self.update_observer(self.OBS_UNFULLSCREEN)
             gtk.gdk.keyboard_ungrab()
+            gtk.gdk.pointer_ungrab()
         
         #while (gtk.events_pending()): gtk.main_iteration()        
         
         self.update_observer(self.OBS_RENDER)
 
-        if (self.__mplayer.has_video()):
+        if (self.__player.has_video()):
             self.__scale_video()
             self.__screen.show()
 
